#
# This is the user-interface definition of a Shiny web application. You can
# run the application by clicking 'Run App' above.
#
# Find out more about building applications with Shiny here:
#


library(shiny)

# Define UI for application 
shinyUI(fluidPage(

  # Application title
  titlePanel("CAZy family analysis"),

  # Slider Layout
  sidebarLayout(
    # Sidebar 
    sidebarPanel(
      textInput("pattern", label = h5("Pattern input"), value = "Enter protein name (e.g. xylosidase) or family (e.g. GH13)..."),
      radioButtons("type", 'Choose Method of searching',
                   c(Cazy_family="FAM",
                     Protein_description="PROT")
      ),
      checkboxInput("org", "Organism"),
      conditionalPanel(
        condition = "input.org == true",
        textInput("organismo", label = h4("Organism name"), value = "e.g. Paenibacillus")
      ),
      actionButton("button1", "1. Click me to retrieve fasta sequences",  style = "background-color:#48D1CC"),
      textInput("filename",label=h5("Genomic reference file"), value = "Paste absolute path to the file (e.g. /home/uoc/my_seq.fa)..."),
      selectInput("evalue1", label = h5("Select evalue for BLAST:"), choices = list("1e-30","1e-30","1e-20","1e-10","1e-5","1e-4","1e-3","1e-2","1e-1","1","10","100"),selected ="1e-2"),
      sliderInput("identity", "identity:", min=0, max=100, step=1, value=0),
      sliderInput("coverage", "coverage:", min=0, max=100, step=1, value=0),
      radioButtons("hits", 'Choose number of hits for each CAZy protein:',
                   c(uniq="uniq",
                     multiple="multiple")
      ),
      radioButtons("outype1", 'Choose type of output for BLAST:',
                   c(dense="dense",
                     full="full")
      ),
      actionButton("button2", "2. Click me to perform BLAST analysis",  style = "background-color:#48D1CC"),
      radioButtons("align", 'Choose program of alignment:',
                   c(Clustal_Omega="clustalo",
                     MUSCLE="muscle")
      ),
      selectInput("evalue2", label = h5("Select evalue for HMMER:"), choices = list("1e-30","1e-30","1e-20","1e-10","1e-5","1e-4","1e-3","1e-2","1e-1","1","10","100"),selected ="1e-5"),
      radioButtons("outype2", 'Choose type of output for HMMER:',
                   c(dense="dense",
                     full="full")
      ),
      actionButton("button3", "3. Click me to perform HMMER analysis",  style = "background-color:#48D1CC"),
      radioButtons("results", 'Choose output for searching functional patterns:',
                   c(BLAST_results="blast",
                     HMMER_results="hmmer")
      ),
      actionButton("button4", "4. Click me to search functional PROSITE patterns",  style = "background-color:#48D1CC")
    ),

    mainPanel(
      h4("Get fasta sequences"),
      verbatimTextOutput("fasta"),
      h4("BLAST results"),
      tableOutput("blast"),
      h4("HMMER results"),
      tableOutput("hmmer"),
      h4("PROSITE results"),
      tableOutput("prosite")
    )
  )
))






